<?php
//=========== the following lines are required so that the sub theme can work  =====================================
remove_action('thesis_hook_header', 'thesis_default_header');
remove_action('thesis_hook_before_header', 'thesis_nav_menu');
remove_action('thesis_hook_custom_template', 'thesis_custom_template_sample');
remove_action('thesis_hook_404_title', 'thesis_404_title');
remove_action('thesis_hook_404_content', 'thesis_404_content');
remove_action('thesis_hook_footer', 'thesis_attribution');
//=========== end of lines ================================================================================
$pathToImageFolder = getImagePath(__FILE__);


//.............................................................................
//	THIS IS WHAT I CONSIDER 'FUNCTIONS.PHP' CODE

//.............................................................................
// REGISTER THE SIDEBARS
do_register_sidebar();

//.............................................................................
// HOME PAGE CUSTOM TEMPLATE
function home_page_right_content_one(){
	if (have_posts()) :
		while (have_posts()) : the_post(); ?>												
			<div id="home_top_message">
				<div id="homepage-imagewrap">
					<?php
					// grabs the post image
					global $post;
					$post_image = thesis_post_image_info('image');
					echo $post_image['output'];
					?>
				</div>
				<div id="home_center_column">
					<?php the_content( ); ?>
				</div>	
				<div id="homepage-menu-wrapper">
					<?php homepage_menus(); ?>
					<ul id="contact-info-wrapper">
					<?php homepage_contact(); ?>
					</ul>
					<ul id="hours-info-wrapper">
					<?php homepage_hours(); ?>
					</ul>
					<ul id="location-info-wrapper">
					<?php homepage_location(); ?>
					</ul>
				</div>
			</div>
<?php 	endwhile; 
	endif; 
}

//.............................................................................
//	OTHER PAGES. ANYTHING NOT THE HOMEPAGE

function other_page_left_content_one() { 
?>

<div id="content">
<div class="post_box top">
<div class="headline_area">
	<?php the_title('<h1>', '</h1>'); ?>
</div>
<div class="format_text">
	<?php the_content( );
	?>
	
</div>
</div>
</div>

<?php }


//.............................................................................
//	RIGHT SIDEBAR 1

function other_page_right_content_one() { 
if (is_page('menus') || is_page('7')) { ?>

<ul class="sidebar_list">
<?php thesis_default_widget(1); ?>
</ul>

<?php } }


//.............................................................................
//.............................................................................
//.............................................................................
//	Custom Footer

function custom_footer(){
?>
<div id="home_bottom_content_row">
	<?php 	
		homepage_footer_01(); 
		homepage_footer_02(); 
		homepage_footer_03(); 
	?>
</div>
<?php }
?>